﻿using System;
using System.Drawing;
using System.Windows.Forms;

using DevExpress.Utils;
using DevExpress.XtraEditors;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.showMessageBoxButton.Click    += showMessageBoxButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 메시지 박스 표시 버튼 클릭시 처리하기 - showMessageBoxButton_Click(sender, e)

        /// <summary>
        /// 메시지 박스 표시 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void showMessageBoxButton_Click(object sender, EventArgs e)
        {
            XtraMessageBoxArgs xtraMessageBoxArgs = new XtraMessageBoxArgs();

            xtraMessageBoxArgs.Owner              = this;
            xtraMessageBoxArgs.Text               = "<b>자료를 삭제하시겠습니까?</b><br>삭제된 자료는 복구할 수 없습니다.";
            xtraMessageBoxArgs.Caption            = "CONFIRMATION";
            xtraMessageBoxArgs.Buttons            = new DialogResult[] { DialogResult.Yes, DialogResult.No };
            xtraMessageBoxArgs.DefaultButtonIndex = 1;
            xtraMessageBoxArgs.AllowHtmlText      = DefaultBoolean.True;

            xtraMessageBoxArgs.Showing += xtraMessageBoxArgs_Showing;

            DialogResult result = XtraMessageBox.Show(xtraMessageBoxArgs);

            if(result == DialogResult.OK)
            {
                // 작업을 처리합니다.
            }
        }

        #endregion
        #region XTRA 메시지 박스 인자 표시시 처리하기 - xtraMessageBoxArgs_Showing(sender, e)

        /// <summary>
        /// XTRA 메시지 박스 인자 표시시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void xtraMessageBoxArgs_Showing(object sender, XtraMessageShowingArgs e)
        {
            foreach(Control control in e.Form.Controls)
            {
                SimpleButton button = control as SimpleButton;

                button.Size    = new Size(100, 30);
                button.Padding = new Padding(3);

                if(button != null)
                {
                    switch(button.DialogResult)
                    {
                        case DialogResult.Yes :

                            button.ImageOptions.Image = Properties.Resources.yes;

                            button.Text = "예(&Y)";

                            break;

                        case DialogResult.No :

                            button.ImageOptions.Image = Properties.Resources.no;

                            button.Text = "아니오(&N)";

                            break;
                    }
                }
            }
        }

        #endregion
    }
}